"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

var _normalizeTokens = _interopRequireDefault(require("./normalizeTokens"));

var _themeToDict = _interopRequireDefault(require("./themeToDict"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class Highlight extends _react.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "prevTheme", void 0);

    _defineProperty(this, "prevLanguage", void 0);

    _defineProperty(this, "themeDict", void 0);

    _defineProperty(this, "getThemeDict", props => {
      if (this.themeDict !== undefined && props.theme === this.prevTheme && props.language === this.prevLanguage) {
        return this.themeDict;
      }

      this.prevTheme = props.theme;
      this.prevLanguage = props.language;
      this.themeDict = props.theme ? (0, _themeToDict.default)(props.theme, props.language) : undefined;
      return this.themeDict;
    });

    _defineProperty(this, "getLineProps", ({
      key,
      className,
      style,
      line: _,
      ...rest
    }) => {
      const output = { ...rest,
        className: 'token-line',
        style: undefined,
        key: undefined
      };
      const themeDict = this.getThemeDict(this.props);

      if (themeDict !== undefined) {
        output.style = themeDict.plain;
      }

      if (style !== undefined) {
        output.style = output.style !== undefined ? { ...output.style,
          ...style
        } : style;
      }

      if (key !== undefined) output.key = key;
      if (className) output.className += ` ${className}`;
      return output;
    });

    _defineProperty(this, "getStyleForToken", ({
      types,
      empty
    }) => {
      const typesSize = types.length;
      const themeDict = this.getThemeDict(this.props);

      if (themeDict === undefined) {
        return undefined;
      }

      if (typesSize === 1 && types[0] === 'plain') {
        return empty ? {
          display: 'inline-block'
        } : undefined;
      }

      if (typesSize === 1 && !empty) {
        return themeDict[types[0]];
      }

      const baseStyle = empty ? {
        display: 'inline-block'
      } : {};
      const typeStyles = types.map(type => themeDict[type]);
      return Object.assign(baseStyle, ...typeStyles);
    });

    _defineProperty(this, "getTokenProps", ({
      key,
      className,
      style,
      token,
      ...rest
    }) => {
      const output = { ...rest,
        className: `token ${token.types.join(' ')}`,
        children: token.content,
        style: this.getStyleForToken(token),
        key: undefined
      };

      if (style !== undefined) {
        output.style = output.style !== undefined ? { ...output.style,
          ...style
        } : style;
      }

      if (key !== undefined) output.key = key;
      if (className) output.className += ` ${className}`;
      return output;
    });
  }

  render() {
    const {
      Prism,
      language,
      code,
      children
    } = this.props;
    const themeDict = this.getThemeDict(this.props);
    const grammar = Prism.languages[language];
    const mixedTokens = grammar !== undefined ? Prism.tokenizeWithHooks(code, grammar, language) : [code];
    const tokens = (0, _normalizeTokens.default)(mixedTokens);
    return children({
      tokens,
      className: `prism-code language-${language}`,
      style: themeDict !== undefined ? themeDict.root : {},
      getLineProps: this.getLineProps,
      getTokenProps: this.getTokenProps
    });
  }

}

var _default = Highlight;
exports.default = _default;