function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { Component } from 'react';
import normalizeTokens from './normalizeTokens';
import themeToDict from './themeToDict';

class Highlight extends Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "prevTheme", void 0);

    _defineProperty(this, "prevLanguage", void 0);

    _defineProperty(this, "themeDict", void 0);

    _defineProperty(this, "getThemeDict", props => {
      if (this.themeDict !== undefined && props.theme === this.prevTheme && props.language === this.prevLanguage) {
        return this.themeDict;
      }

      this.prevTheme = props.theme;
      this.prevLanguage = props.language;
      this.themeDict = props.theme ? themeToDict(props.theme, props.language) : undefined;
      return this.themeDict;
    });

    _defineProperty(this, "getLineProps", ({
      key,
      className,
      style,
      line: _,
      ...rest
    }) => {
      const output = { ...rest,
        className: 'token-line',
        style: undefined,
        key: undefined
      };
      const themeDict = this.getThemeDict(this.props);

      if (themeDict !== undefined) {
        output.style = themeDict.plain;
      }

      if (style !== undefined) {
        output.style = output.style !== undefined ? { ...output.style,
          ...style
        } : style;
      }

      if (key !== undefined) output.key = key;
      if (className) output.className += ` ${className}`;
      return output;
    });

    _defineProperty(this, "getStyleForToken", ({
      types,
      empty
    }) => {
      const typesSize = types.length;
      const themeDict = this.getThemeDict(this.props);

      if (themeDict === undefined) {
        return undefined;
      }

      if (typesSize === 1 && types[0] === 'plain') {
        return empty ? {
          display: 'inline-block'
        } : undefined;
      }

      if (typesSize === 1 && !empty) {
        return themeDict[types[0]];
      }

      const baseStyle = empty ? {
        display: 'inline-block'
      } : {};
      const typeStyles = types.map(type => themeDict[type]);
      return Object.assign(baseStyle, ...typeStyles);
    });

    _defineProperty(this, "getTokenProps", ({
      key,
      className,
      style,
      token,
      ...rest
    }) => {
      const output = { ...rest,
        className: `token ${token.types.join(' ')}`,
        children: token.content,
        style: this.getStyleForToken(token),
        key: undefined
      };

      if (style !== undefined) {
        output.style = output.style !== undefined ? { ...output.style,
          ...style
        } : style;
      }

      if (key !== undefined) output.key = key;
      if (className) output.className += ` ${className}`;
      return output;
    });
  }

  render() {
    const {
      Prism,
      language,
      code,
      children
    } = this.props;
    const themeDict = this.getThemeDict(this.props);
    const grammar = Prism.languages[language];
    const mixedTokens = grammar !== undefined ? Prism.tokenizeWithHooks(code, grammar, language) : [code];
    const tokens = normalizeTokens(mixedTokens);
    return children({
      tokens,
      className: `prism-code language-${language}`,
      style: themeDict !== undefined ? themeDict.root : {},
      getLineProps: this.getLineProps,
      getTokenProps: this.getTokenProps
    });
  }

}

export default Highlight;